# windows-installer-assets

Files and binaries need for the Spyder Windows installer build

List of resources:

* `jedi` compiled subprocess `__main__.py` patched version
* NSIS files and plugins to build the installer with a context menu entry that can be used with `pynsist`
* `tkinter` binaries and files for Python 3.8.10
* `pylint` `modify_sys_path` function from `__init__.py` modification
* `micromamba` executable version `0.25.1`
